@@ -3,7 +3,7 @@
 """
     migrate phpBB3 to DjangoBB
     ~~~~~~~~~~~~~~~~~~~~~~~~~~
-    
+
 
     :copyleft: 2012 by the django-phpBB3 team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
@@ -16,6 +16,7 @@ import sys
 import time
 import shutil
 import pprint
+from django.utils.encoding import smart_unicode
 
 if __name__ == "__main__":
     os.environ["DJANGO_SETTINGS_MODULE"] = "phpBB2DjangoBB_project.settings"
@@ -52,7 +53,7 @@ from django_phpBB3.utils import ProcessInfo, human_duration
 def disable_auto_fields(model_class):
     """
     Hack: It's needed to disable "auto_now_add" to set a old datetime
-    
+
     see also: http://stackoverflow.com/questions/7499767/temporarily-disable-auto-now-auto-now-add
     """
     ATTR_NAMES = ("auto_now", "auto_now_add")
@@ -103,7 +104,7 @@ class Command(BaseCommand):
         self.update_topic_stats()
         self.update_forum_stats()
 
-        self.stdout.write("\nmigration done.\n")
+        self.stdout.write(u"\nmigration done.\n")
 
     def _warn(self, msg):
         self.stderr.write(self.style.ERROR(msg))
@@ -138,7 +139,7 @@ class Command(BaseCommand):
 
 
     def migrate_users(self, cleanup_users, moderator_groups):
-        self.stdout.write("\n *** Migrate phpbb_forum users...\n")
+        self.stdout.write(u"\n *** Migrate phpbb_forum users...\n")
 
         lang_codes = [i[0] for i in settings.LANGUAGES]
         default_lang = settings.LANGUAGE_CODE.split("-")[0]
@@ -151,15 +152,15 @@ class Command(BaseCommand):
                 # Only users with has no posts can be skip.
                 if cleanup_users >= 1:
                     if not phpbb_user.email:
-                        self.stdout.write("\t * Skip '%s' (no email)\n" % phpbb_user)
+                        self.stdout.write(u"\t * Skip '%s' (no email)\n" % smart_unicode(phpbb_user.username))
                         continue
                 if cleanup_users >= 2:
                     if not phpbb_user.lastvisit:
-                        self.stdout.write("\t * Skip '%s' (no lastvisit)\n" % phpbb_user)
+                        self.stdout.write(u"\t * Skip '%s' (no lastvisit)\n" % smart_unicode(phpbb_user.username))
                         continue
                 if cleanup_users >= 3:
                     if not phpbb_user.posts:
-                        self.stdout.write("\t * Skip '%s' (no posts)\n" % phpbb_user)
+                        self.stdout.write(u"\t * Skip '%s' (no posts)\n" % smart_unicode(phpbb_user.username))
                         continue
 
             last_login = phpbb_user.lastvisit_datetime()
@@ -167,6 +168,10 @@ class Command(BaseCommand):
                 # can't be None in User model:
                 last_login = datetime.datetime(year=datetime.MINYEAR, month=1, day=1)
 
+            # FIXME:
+            #     * Clean username (remove non-ascii)
+            #     * check doublicates via email compare 
+
             django_user, created = User.objects.get_or_create(
                 username=phpbb_user.username,
                 defaults={
@@ -179,14 +184,14 @@ class Command(BaseCommand):
                 }
             )
             if created:
-                self.stdout.write("\tUser '%s' created.\n" % django_user)
+                self.stdout.write(u"\tUser '%s' created.\n" % smart_unicode(django_user.username))
                 django_user.set_unusable_password()
                 django_user.save()
             else:
-                self.stdout.write("\tUser '%s' exists.\n" % django_user)
+                self.stdout.write(u"\tUser '%s' exists.\n" % smart_unicode(django_user.username))
 
             if phpbb_user.group in moderator_groups:
-                self.stdout.write("\t *** Mark user '%s' as global forum moderator\n" % phpbb_user)
+                self.stdout.write(u"\t *** Mark user '%s' as global forum moderator\n" % phpbb_user)
                 moderators.append(django_user)
 
             user_dict[phpbb_user.id] = django_user
@@ -222,24 +227,24 @@ class Command(BaseCommand):
                 }
             )
             if created:
-                self.stdout.write("\t - User profile for '%s' created.\n" % django_user)
+                self.stdout.write(u"\t - User profile for '%s' created.\n" % smart_unicode(django_user.username))
             else:
-                self.stdout.write("\t - User profile for '%s' exists.\n" % django_user)
+                self.stdout.write(u"\t - User profile for '%s' exists.\n" % smart_unicode(django_user.username))
 
         return user_dict, moderators
 
     def get_or_create_category(self, phpbb_forum):
         obj, created = Category.objects.get_or_create(
-            name=phpbb_forum.forum_name
+            name=smart_unicode(phpbb_forum.forum_name)
         )
         if created:
-            self.stdout.write("\tCategory '%s' created.\n" % obj)
+            self.stdout.write(u"\tCategory '%s' created.\n" % obj.name)
         else:
-            self.stdout.write("\tCategory '%s' exists.\n" % obj)
+            self.stdout.write(u"\tCategory '%s' exists.\n" % obj.name)
         return obj
 
     def migrate_forums(self, moderators):
-        self.stdout.write("\n *** Migrate phpbb_forum entries...\n")
+        self.stdout.write(u"\n *** Migrate phpbb_forum entries...\n")
 
         phpbb_forums = phpbb_Forum.objects.all()
 
@@ -279,7 +284,7 @@ class Command(BaseCommand):
                 category_dict[parent.id] = category
 
             obj, created = Forum.objects.get_or_create(
-                name=phpbb_forum.forum_name,
+                name=smart_unicode(phpbb_forum.forum_name),
                 defaults={
                     "category":category,
                     "description":phpbb_forum.forum_desc,
@@ -291,27 +296,27 @@ class Command(BaseCommand):
                 }
             )
             if created:
-                self.stdout.write("\tForum '%s' created.\n" % obj)
+                self.stdout.write(u"\tForum '%s' created.\n" % smart_unicode(obj.name))
             else:
-                self.stdout.write("\tForum '%s' exists.\n" % obj)
+                self.stdout.write(u"\tForum '%s' exists.\n" % smart_unicode(obj.name))
 
             forum_dict[phpbb_forum.id] = obj
 
             for moderator in moderators:
                 obj.moderators.add(moderator)
             obj.save()
-            self.stdout.write("\t - moderators: %s\n" % obj.moderators.all())
+            self.stdout.write(u"\t - moderators: %s\n" % obj.moderators.all())
 
         return forum_dict
 
 
     def migrate_topic(self, user_dict, forum_dict):
-        self.stdout.write("\n *** Migrate phpBB topic entries...\n")
+        self.stdout.write(u"\n *** Migrate phpBB topic entries...\n")
 
-        self.stdout.write("\tget topic watch information...")
+        self.stdout.write(u"\tget topic watch information...")
         self.stdout.flush()
         topic_watch = get_topic_watch()
-        self.stdout.write("OK\n")
+        self.stdout.write(u"OK\n")
         self.stdout.flush()
 
         topic_dict = {}
@@ -347,6 +352,7 @@ class Command(BaseCommand):
                 sticky = False
 
             obj = Topic.objects.create(
+                id=topic.id,
                 forum=forum,
                 user=user,
                 name=topic.clean_title(),
@@ -376,7 +382,7 @@ class Command(BaseCommand):
 
 
     def migrate_posts(self, user_dict, topic_dict):
-        self.stdout.write("\n *** Migrate phpBB posts entries...\n")
+        self.stdout.write(u"\n *** Migrate phpBB posts entries...\n")
 
         posts = phpbb_Post.objects.all().order_by("time")
         total = posts.count()
@@ -407,6 +413,7 @@ class Command(BaseCommand):
 
             try:
                 post = Post.objects.create(
+                    id=phpbb_post.id,
                     topic=topic,
                     user=user,
                     created=phpbb_post.create_datetime(),
@@ -418,6 +425,7 @@ class Command(BaseCommand):
                     user_ip=phpbb_post.poster_ip,
                 )
             except Exception, err:
+                raise
                 msg = (
                     "\n +++ ERROR: creating Post entry for phpBB3 post (ID: %s):\n"
                     "%s\n"
@@ -427,31 +435,32 @@ class Command(BaseCommand):
 
             if phpbb_post.has_attachment():
                 # copy attachment files
-                phpbb_attachment = phpbb_Attachment.objects.get(post_msg=phpbb_post)
-                src_path = os.path.join(settings.PHPBB_ATTACHMENT_PATH, phpbb_attachment.physical_filename)
-                if not os.path.isfile(src_path):
-                    self._warn("\n +++ ERROR: Attachment not found: '%s'\n" % src_path)
-                else:
-                    attachment = Attachment(
-                        size=phpbb_attachment.filesize,
-                        content_type=phpbb_attachment.mimetype,
-                        name=phpbb_attachment.real_filename,
-                        post=post
-                    )
-                    filename = "%d.0" % post.id
-                    dst_path = os.path.join(
-                        settings.MEDIA_ROOT, forum_settings.ATTACHMENT_UPLOAD_TO,
-                        filename
-                    )
-                    shutil.copy(src_path, dst_path)
-                    attachment.path = filename
-                    attachment.save()
-                    self.stdout.write(
-                        "\n\t *** Attachment %s copied in: %s\n" % (
-                            attachment, dst_path
+                phpbb_attachments = phpbb_Attachment.objects.filter(post_msg=phpbb_post)
+                for phpbb_attachment in phpbb_attachments:
+                    src_path = os.path.join(settings.PHPBB_ATTACHMENT_PATH, phpbb_attachment.physical_filename)
+                    if not os.path.isfile(src_path):
+                        self._warn("\n +++ ERROR: Attachment not found: '%s'\n" % src_path)
+                    else:
+                        attachment = Attachment(
+                            size=phpbb_attachment.filesize,
+                            content_type=phpbb_attachment.mimetype,
+                            name=phpbb_attachment.real_filename,
+                            post=post
                         )
-                    )
-                    self.stdout.flush()
+                        filename = "%d.0" % post.id
+                        dst_path = os.path.join(
+                            settings.MEDIA_ROOT, forum_settings.ATTACHMENT_UPLOAD_TO,
+                            filename
+                        )
+                        shutil.copy(src_path, dst_path)
+                        attachment.path = filename
+                        attachment.save()
+                        self.stdout.write(
+                            "\n\t *** Attachment %s copied in: %s\n" % (
+                                attachment.name, dst_path
+                            )
+                        )
+                        self.stdout.flush()
 
         duration = time.time() - start_time
         rate = float(count) / duration
@@ -462,7 +471,7 @@ class Command(BaseCommand):
         )
 
     def update_topic_stats(self):
-        self.stdout.write("\n *** set topic stats...\n")
+        self.stdout.write(u"\n *** set topic stats...\n")
 
         topics = Topic.objects.all()
         total = topics.count()
@@ -503,10 +512,10 @@ class Command(BaseCommand):
         )
 
     def update_forum_stats(self):
-        self.stdout.write("\n *** set forum stats...\n")
+        self.stdout.write(u"\n *** set forum stats...\n")
 
         for forum in Forum.objects.all():
-            self.stdout.write("\tset stats for %s\n" % forum)
+            self.stdout.write(u"\tset stats for %s\n" % forum)
             queryset = Post.objects.all().filter(topic__forum=forum)
             forum.post_count = queryset.count()
             try:
