@@ -10,10 +10,13 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-import re
 import htmlentitydefs as entities
+import re
 import time
 
+from django.utils.encoding import force_unicode
+
+
 EMAIL_RE = (
     re.compile(r' ?<!-- e --><a href="([^"]*)">(.*?)</a><!-- e --> ?', re.S),
     r' [url=\1]\2[/url] '
@@ -69,9 +72,9 @@ class Deentity(object):
 
     def replace_named(self, text):
         """ named entity """
-        if text == "nbsp":
+        if text == u"nbsp":
             # Non breaking spaces is not in htmlentitydefs
-            return " "
+            return u" "
         else:
             codepoint = entities.name2codepoint[text]
             return unichr(codepoint)
@@ -95,8 +98,8 @@ deentity = Deentity()
 
 def phpbb_html2bbcode(text):
     """
-    >>> phpbb_html2bbcode('DjangoBB <!-- m --><a class="postlink" href="http://djangobb.org/">trac</a><!-- m --> page.')
-    'DjangoBB [url=http://djangobb.org/]trac[/url] page.'
+    >>> phpbb_html2bbcode(u'DjangoBB <!-- m --><a class="postlink" href="http://djangobb.org/">trac</a><!-- m --> page.')
+    u'DjangoBB [url=http://djangobb.org/]trac[/url] page.'
     """
     for regex, replace_by in BBCODE_REPLACES:
         text = regex.sub(replace_by, text)
@@ -106,7 +109,7 @@ def phpbb_html2bbcode(text):
 def clean_bbcode(text, bbcode_uid=None):
     """
     >>> clean_bbcode('DjangoBB <!-- m --><a class="postlink" href="http://djangobb.org/">trac</a><!-- m --> page.')
-    'DjangoBB [url=http://djangobb.org/]trac[/url] page.'
+    u'DjangoBB [url=http://djangobb.org/]trac[/url] page.'
 
     >>> clean_bbcode(
     ...     u'Look at [url=https&#58;//github&#46;com/jedie/PyLucid/views&#46;py:1234abcd]/views.py[/url:1234abcd]',
@@ -114,8 +117,10 @@ def clean_bbcode(text, bbcode_uid=None):
     ... )
     u'Look at [url=https://github.com/jedie/PyLucid/views.py]/views.py[/url]'
     """
+    text = force_unicode(text)
+
     if bbcode_uid is not None:
-        text = text.replace(":%s" % bbcode_uid, "")
+        text = text.replace(u":%s" % bbcode_uid, u"")
 
     text = deentity.replace_all(text)
 
