@@ -1,15 +1,28 @@
 # coding: utf-8
 
 from django.conf import settings
-from django.conf.urls import patterns, include
+from django.conf.urls import patterns, include, url
 from django.contrib import admin
 from django.views.generic.simple import direct_to_template
 
+from django_phpBB3.views import redirect_phpbb2django
+
+from phpBB2DjangoBB_project.views import migrate
+
 
 admin.autodiscover()
 
 
 urlpatterns = patterns('',
+    # example phpBB -> DjangoBB redirect views:
+    url(
+        r"^%s/viewtopic.php" % settings.OLD_PHPBB_URL_PREFIX,
+        redirect_phpbb2django
+    ),
+
+    # for developing only
+    (r'^migrate/', migrate),
+
     # Admin
     (r'^admin/', include(admin.site.urls)),
 
